arc_length

Function arc_length 

pub fn arc_length<T>(arc: &[Point<T>], closed: bool) -> f64
where T: NumCast + Copy,
Computes the length of an arc. If closed is set to true then the distance between the last and the first point is included in the total length.