HogOptions

Struct HogOptions 

pub struct HogOptions {
    pub orientations: usize,
    pub signed: bool,
    pub cell_side: usize,
    pub block_side: usize,
    pub block_stride: usize,
}
Parameters for HoG descriptors.

Fields

orientations: usize

Number of gradient orientation bins.

signed: bool

Whether gradients in opposite directions are treated as equal.

cell_side: usize

Width and height of cell in pixels.

block_side: usize

Width and height of block in cells.

block_stride: usize

Offset of the start of one block from the next in cells.

Implementations

Source

impl HogOptions

pub fn new( orientations: usize, signed: bool, cell_side: usize, block_side: usize, block_stride: usize, ) -> HogOptions

User-provided options, prior to validation.