HogSpec

Struct HogSpec 

pub struct HogSpec { /* private fields */ }
HoG options plus values calculated from these options and the desired image dimensions. Validation must occur when instances of this struct are created - functions receiving a spec will assume that it is valid.

Implementations

Source

impl HogSpec

pub fn from_options( width: u32, height: u32, options: HogOptions, ) -> Result<HogSpec, String>

Returns an error message if image dimensions aren’t compatible with the provided options.

pub fn descriptor_length(&self) -> usize

The total size in floats of the HoG descriptor with these dimensions.