intersection_points

Function intersection_points 

pub fn intersection_points(
    line: PolarLine,
    image_width: u32,
    image_height: u32,
) -> Option<((f32, f32), (f32, f32))>
Returns the intersection points of a PolarLine with an image of given width and height, or None if the line and image bounding box are disjoint. The x value of an intersection point lies within the closed interval [0, image_width] and the y value within the closed interval [0, image_height].