Functions for adding synthetic noise to images.
Functions
- gaussian_
noise - Adds independent additive Gaussian noise to all channels of an image, with the given mean and standard deviation.
- gaussian_
noise_ mut - An in-place version of
gaussian_noise(). - salt_
and_ pepper_ noise - Converts pixels to black or white at the given
rate(between 0.0 and 1.0). Black and white occur with equal probability. - salt_
and_ pepper_ noise_ mut - An in-place version of
salt_and_pepper_noise().