Module template_matching

Module template_matching 

Functions for performing template matching.

Structs

Extremes
The largest and smallest values in an image, together with their locations.

Enums

MatchTemplateMethod
Scoring functions when comparing a template and an image region.

Functions

find_extremes
Finds the largest and smallest values in an image and their locations. If there are multiple such values then the lexicographically smallest is returned.
match_template
Slides a template over an image and scores the match at each point using the requested method.
match_template_parallel
Slides a template over an image and scores the match at each point using the requested method. This version uses rayon to parallelize the computation.
match_template_with_mask
Slides a template and a mask over an image and scores the match at each point using the requested method.
match_template_with_mask_parallel
Slides a template and a mask over an image and scores the match at each point using the requested method. This version uses rayon to parallelize the computation.