Norm

Enum Norm 

pub enum Norm {
    L1,
    L2,
    LInf,
}
How to measure distance between coordinates. See distance_transform for examples.

Variants



L1

d((x1, y1), (x2, y2)) = abs(x1 - x2) + abs(y1 - y2)

Also known as the Manhattan or city block norm.



L2

d((x1, y1), (x2, y2)) = sqrt((x1 - x2)^2 + (y1 - y2)^2)

Also known as the Euclidean norm.

Note that both distance_transform and the functions in the morphology module represent distances as integer values, so cannot accurately represent L2 norms. Instead, these functions approximate the L2 norm by taking the ceiling of the true value. If you want accurate distances then use euclidean_squared_distance_transform instead, which returns floating point values.



LInf

d((x1, y1), (x2, y2)) = max(abs(x1 - x2), abs(y1 - y2))

Also known as the chessboard norm.