pub struct HogOptions {
pub orientations: usize,
pub signed: bool,
pub cell_side: usize,
pub block_side: usize,
pub block_stride: usize,
}Expand description
Parameters for HoG descriptors.
Fields
orientations: usizeNumber of gradient orientation bins.
signed: boolWhether gradients in opposite directions are treated as equal.
cell_side: usizeWidth and height of cell in pixels.
block_side: usizeWidth and height of block in cells.
block_stride: usizeOffset of the start of one block from the next in cells.
Implementations