Functions for performing template matching.
Structs
- Extremes
- The largest and smallest values in an image, together with their locations.
Enums
- Match
Template Method - Scoring functions when comparing a template and an image region.
Functions
- find_
extremes - Finds the largest and smallest values in an image and their locations. If there are multiple such values then the lexicographically smallest is returned.
- match_
template - Slides a
templateover animageand scores the match at each point using the requestedmethod. - match_
template_ parallel - Slides a
templateover animageand scores the match at each point using the requestedmethod. This version uses rayon to parallelize the computation. - match_
template_ with_ mask - Slides a
templateand amaskover animageand scores the match at each point using the requestedmethod. - match_
template_ with_ mask_ parallel - Slides a
templateand amaskover animageand scores the match at each point using the requestedmethod. This version uses rayon to parallelize the computation.